========================
Authors and contributors
========================

The following people have contributed code and/or ideas to the current version
of Neo. The institutional affiliations are those at the time of the contribution,
and may not be the current affiliation of a contributor.

* Samuel Garcia [1]
* Andrew Davison [2, 21]
* Chris Rodgers [3]
* Pierre Yger [2]
* Yann Mahnoun [4]
* Luc Estabanez [2]
* Andrey Sobolev [5]
* Thierry Brizzi [2]
* Florent Jaillet [6]
* Philipp Rautenberg [5]
* Thomas Wachtler [5]
* Cyril Dejean [7]
* Robert Pröpper [8]
* Domenico Guarino [2]
* Achilleas Koutsou [5]
* Erik Li [9]
* Georg Raiser [10]
* Joffrey Gonin [2]
* Kyler Brown
* Mikkel Elle Lepperød [11]
* C Daniel Meliza [12]
* Michael Denker [13, 29]
* Julia Sprenger [13, 6]
* Maximilian Schmidt [13]
* Johanna Senk [13]
* Carlos Canova [13]
* Hélissande Fragnaud [2]
* Mark Hollenbeck [14]
* Mieszko Grodzicki
* Rick Gerkin [15]
* Matthieu Sénoville [2]
* Chadwick Boulay [16]
* Björn Müller [13]
* William Hart [17]
* erikli(github)
* Jeffrey Gill [18]
* Lucas (lkoelman@github)
* Mark Histed
* Mike Sintsov [19]
* Scott W Harden [20]
* Chek Yin Choi (hkchekc@github)
* Corentin Fragnaud [21]
* Alexander Kleinjohann
* Christian Kothe
* rishidhingra@github
* Hugo van Kemenade
* Aitor Morales-Gregorio [13]
* Peter N Steinmetz [22]
* Shashwat Sridhar
* Alessio Buccino [23, 24, 38]
* Regimantas Jurkus [13]
* Steffen Buergers [24]
* Etienne Combrisson [6]
* Ben Dichter [24]
* Elodie Legouée [21]
* Oliver Kloss [13]
* Heberto Mayorquin [24]
* Thomas Perret [25]
* Kyle Johnsen [26, 27]
* Zach McKenzie [28,39]
* Moritz Alexander Kern [29]
* Joscha Schmiedt
* Daniel P. Crepeau [30]
* Divyansh Gupta [31]
* Nate Dolensek [3]
* Philipp Hornauer [32]
* Robert Wolff
* Jules Lebert [33]
* Benjamin Heasly
* Baptiste Grimaud [34]
* Cody Baker [24]
* Fernando J. Chaure [35]
* Filipe*github
* Matthias Klumpp
* Greg Knoll [36]
* Chris Halcrow [37]
* Szonja Weigl [24]
* Chris Heydrick [40]
* Kyu Hun Lee
* Téo Lohrer
* Anthony Pinto [41]
* Xin Niu

1. Centre de Recherche en Neuroscience de Lyon, CNRS UMR5292 - INSERM U1028 - Universite Claude Bernard Lyon 1
2. Unité de Neuroscience, Information et Complexité, CNRS UPR 3293, Gif-sur-Yvette, France
3. University of California, Berkeley
4. Laboratoire de Neurosciences Intégratives et Adaptatives, CNRS UMR 6149 - Université de Provence, Marseille, France
5. G-Node, Ludwig-Maximilians-Universität, Munich, Germany
6. Institut de Neurosciences de la Timone, CNRS UMR 7289 - Université d'Aix-Marseille, Marseille, France
7. Centre de Neurosciences Integratives et Cognitives, UMR 5228 - CNRS - Université Bordeaux I - Université Bordeaux II
8. Neural Information Processing Group, TU Berlin, Germany
9. Department of Neurobiology & Anatomy, Drexel University College of Medicine, Philadelphia, PA, USA
10. University of Konstanz, Konstanz, Germany
11. Centre for Integrative Neuroplasticity (CINPLA), University of Oslo, Norway
12. University of Virginia
13. INM-6, Forschungszentrum Jülich, Germany
14. University of Texas at Austin
15. Arizona State University
16. Ottawa Hospital Research Institute, Canada
17. Swinburne University of Technology, Australia
18. Case Western Reserve University (CWRU) · Department of Biology
19. IAL Developmental Neurobiology, Kazan Federal University, Kazan, Russia
20. Harden Technologies, LLC
21. Institut des Neurosciences Paris-Saclay, CNRS UMR 9197 - Université Paris-Sud, Gif-sur-Yvette, France
22. Neurtex Brain Research Institute, Dallas, TX, USAs
23. Bio Engineering Laboratory, DBSSE, ETH, Basel, Switzerland
24. CatalystNeuro
25. Institut des Sciences Cognitives Marc Jeannerod, CNRS UMR5229, Lyon, France
26. Georgia Institute of Technology
27. Emory University
28. Harvard Medical School
29. Institute for Advanced Simulation (IAS-6), Forschungszentrum Jülich, Germany
30. Dark Horse Neuro, Inc.
31. IST Austria
32. Department of Biosystems Science and Engineering, ETH Zürich, Basel, Switzerland
33. University College London
34. École Normale Supérieure Paris-Saclay
35. Institute of Biomedical Engineering, University of Buenos Aires, Argentina
36. Bernstein Center for Computational Neuroscience, Berlin, Germany
37. University of Edinburgh
38. Allen Institute for Neural Dynamics, Seattle, WA, United States
39. Massachusetts General Hospital, Department of Molecular Biology
40. Plexon Inc.
41. Paris Brain Institute



If we've somehow missed you off the list we're very sorry - please let us know.


Acknowledgements
----------------

.. image:: https://www.braincouncil.eu/wp-content/uploads/2018/11/wsi-imageoptim-EU-Logo.jpg
   :alt: "EU Logo"
   :height: 104px
   :width: 156px
   :align: right

Development of Neo has been partially funded by the European Union Sixth Framework Program (FP6) under
grant agreement FETPI-015879 (FACETS), by the European Union Seventh Framework Program (FP7/2007­-2013)
under grant agreements no. 269921 (BrainScaleS) and no. 604102 (HBP),
and by the European Union's Horizon 2020 Framework Programme for
Research and Innovation under the Specific Grant Agreements No. 720270 (Human Brain Project SGA1),
No. 785907 (Human Brain Project SGA2) and No. 945539 (Human Brain Project SGA3).
